==> istio-model-1.0.0-sources.jar: me/snowdrop/istio/mixer/adapter/stackdriver/SinkInfoFluentImpl.java <==
package me.snowdrop.istio.mixer.adapter.stackdriver;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class SinkInfoFluentImpl<A extends SinkInfoFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements SinkInfoFluent<A>{

    private Boolean uniqueWriterIdentity;
    private Boolean updateDestination;
    private Boolean updateFilter;
    private Boolean updateIncludeChildren;
    private String destination;
    private String filter;
    private String id;

    public SinkInfoFluentImpl(){
    }
    public SinkInfoFluentImpl(SinkInfo instance){
            this.withUniqueWriterIdentity(instance.getUniqueWriterIdentity()); 
            this.withUpdateDestination(instance.getUpdateDestination()); 
            this.withUpdateFilter(instance.getUpdateFilter()); 
            this.withUpdateIncludeChildren(instance.getUpdateIncludeChildren()); 
            this.withDestination(instance.getDestination()); 
            this.withFilter(instance.getFilter()); 
            this.withId(instance.getId()); 
    }

    public Boolean isUniqueWriterIdentity(){
            return this.uniqueWriterIdentity;
    }

    public A withUniqueWriterIdentity(Boolean uniqueWriterIdentity){
            this.uniqueWriterIdentity=uniqueWriterIdentity; return (A) this;
    }

    public Boolean hasUniqueWriterIdentity(){
            return this.uniqueWriterIdentity != null;
    }

    public A withNewUniqueWriterIdentity(String arg1){
            return (A)withUniqueWriterIdentity(new Boolean(arg1));
    }

    public A withNewUniqueWriterIdentity(boolean arg1){
            return (A)withUniqueWriterIdentity(new Boolean(arg1));
    }

    public Boolean isUpdateDestination(){
            return this.updateDestination;
    }

    public A withUpdateDestination(Boolean updateDestination){
            this.updateDestination=updateDestination; return (A) this;
    }

    public Boolean hasUpdateDestination(){
            return this.updateDestination != null;
    }

    public A withNewUpdateDestination(String arg1){
            return (A)withUpdateDestination(new Boolean(arg1));
    }

    public A withNewUpdateDestination(boolean arg1){
            return (A)withUpdateDestination(new Boolean(arg1));
    }

    public Boolean isUpdateFilter(){
            return this.updateFilter;
    }

    public A withUpdateFilter(Boolean updateFilter){
            this.updateFilter=updateFilter; return (A) this;
    }

    public Boolean hasUpdateFilter(){
            return this.updateFilter != null;
    }

    public A withNewUpdateFilter(String arg1){
            return (A)withUpdateFilter(new Boolean(arg1));
    }

    public A withNewUpdateFilter(boolean arg1){
            return (A)withUpdateFilter(new Boolean(arg1));
    }

    public Boolean isUpdateIncludeChildren(){
            return this.updateIncludeChildren;
    }

    public A withUpdateIncludeChildren(Boolean updateIncludeChildren){
            this.updateIncludeChildren=updateIncludeChildren; return (A) this;
    }

    public Boolean hasUpdateIncludeChildren(){
            return this.updateIncludeChildren != null;
    }

    public A withNewUpdateIncludeChildren(String arg1){
            return (A)withUpdateIncludeChildren(new Boolean(arg1));
    }

    public A withNewUpdateIncludeChildren(boolean arg1){
            return (A)withUpdateIncludeChildren(new Boolean(arg1));
    }

    public String getDestination(){
            return this.destination;
    }

    public A withDestination(String destination){
            this.destination=destination; return (A) this;
    }

    public Boolean hasDestination(){
            return this.destination != null;
    }

    public String getFilter(){
            return this.filter;
    }

    public A withFilter(String filter){
            this.filter=filter; return (A) this;
    }

    public Boolean hasFilter(){
            return this.filter != null;
    }

    public String getId(){
            return this.id;
    }

    public A withId(String id){
            this.id=id; return (A) this;
    }

    public Boolean hasId(){
            return this.id != null;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            SinkInfoFluentImpl that = (SinkInfoFluentImpl) o;
            if (uniqueWriterIdentity != null ? !uniqueWriterIdentity.equals(that.uniqueWriterIdentity) :that.uniqueWriterIdentity != null) return false;
            if (updateDestination != null ? !updateDestination.equals(that.updateDestination) :that.updateDestination != null) return false;
            if (updateFilter != null ? !updateFilter.equals(that.updateFilter) :that.updateFilter != null) return false;
            if (updateIncludeChildren != null ? !updateIncludeChildren.equals(that.updateIncludeChildren) :that.updateIncludeChildren != null) return false;
            if (destination != null ? !destination.equals(that.destination) :that.destination != null) return false;
            if (filter != null ? !filter.equals(that.filter) :that.filter != null) return false;
            if (id != null ? !id.equals(that.id) :that.id != null) return false;
            return true;
    }




}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/mixer/adapter/stackdriver/SinkInfoFluentImpl.java <==
package me.snowdrop.istio.mixer.adapter.stackdriver;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class SinkInfoFluentImpl<A extends SinkInfoFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements SinkInfoFluent<A>{

    private Boolean uniqueWriterIdentity;
    private Boolean updateDestination;
    private Boolean updateFilter;
    private Boolean updateIncludeChildren;
    private String destination;
    private String filter;
    private String id;

    public SinkInfoFluentImpl(){
    }
    public SinkInfoFluentImpl(SinkInfo instance){
            this.withUniqueWriterIdentity(instance.getUniqueWriterIdentity()); 
            this.withUpdateDestination(instance.getUpdateDestination()); 
            this.withUpdateFilter(instance.getUpdateFilter()); 
            this.withUpdateIncludeChildren(instance.getUpdateIncludeChildren()); 
            this.withDestination(instance.getDestination()); 
            this.withFilter(instance.getFilter()); 
            this.withId(instance.getId()); 
    }

    public Boolean isUniqueWriterIdentity(){
            return this.uniqueWriterIdentity;
    }

    public A withUniqueWriterIdentity(Boolean uniqueWriterIdentity){
            this.uniqueWriterIdentity=uniqueWriterIdentity; return (A) this;
    }

    public Boolean hasUniqueWriterIdentity(){
            return this.uniqueWriterIdentity != null;
    }

    public A withNewUniqueWriterIdentity(String arg1){
            return (A)withUniqueWriterIdentity(new Boolean(arg1));
    }

    public A withNewUniqueWriterIdentity(boolean arg1){
            return (A)withUniqueWriterIdentity(new Boolean(arg1));
    }

    public Boolean isUpdateDestination(){
            return this.updateDestination;
    }

    public A withUpdateDestination(Boolean updateDestination){
            this.updateDestination=updateDestination; return (A) this;
    }

    public Boolean hasUpdateDestination(){
            return this.updateDestination != null;
    }

    public A withNewUpdateDestination(String arg1){
            return (A)withUpdateDestination(new Boolean(arg1));
    }

    public A withNewUpdateDestination(boolean arg1){
            return (A)withUpdateDestination(new Boolean(arg1));
    }

    public Boolean isUpdateFilter(){
            return this.updateFilter;
    }

    public A withUpdateFilter(Boolean updateFilter){
            this.updateFilter=updateFilter; return (A) this;
    }

    public Boolean hasUpdateFilter(){
            return this.updateFilter != null;
    }

    public A withNewUpdateFilter(String arg1){
            return (A)withUpdateFilter(new Boolean(arg1));
    }

    public A withNewUpdateFilter(boolean arg1){
            return (A)withUpdateFilter(new Boolean(arg1));
    }

    public Boolean isUpdateIncludeChildren(){
            return this.updateIncludeChildren;
    }

    public A withUpdateIncludeChildren(Boolean updateIncludeChildren){
            this.updateIncludeChildren=updateIncludeChildren; return (A) this;
    }

    public Boolean hasUpdateIncludeChildren(){
            return this.updateIncludeChildren != null;
    }

    public A withNewUpdateIncludeChildren(String arg1){
            return (A)withUpdateIncludeChildren(new Boolean(arg1));
    }

    public A withNewUpdateIncludeChildren(boolean arg1){
            return (A)withUpdateIncludeChildren(new Boolean(arg1));
    }

    public String getDestination(){
            return this.destination;
    }

    public A withDestination(String destination){
            this.destination=destination; return (A) this;
    }

    public Boolean hasDestination(){
            return this.destination != null;
    }

    public A withNewDestination(String arg1){
            return (A)withDestination(new String(arg1));
    }

    public A withNewDestination(StringBuilder arg1){
            return (A)withDestination(new String(arg1));
    }

    public A withNewDestination(StringBuffer arg1){
            return (A)withDestination(new String(arg1));
    }

    public String getFilter(){
            return this.filter;
    }

    public A withFilter(String filter){
            this.filter=filter; return (A) this;
    }

    public Boolean hasFilter(){
            return this.filter != null;
    }

    public A withNewFilter(String arg1){
            return (A)withFilter(new String(arg1));
    }

    public A withNewFilter(StringBuilder arg1){
            return (A)withFilter(new String(arg1));
    }

    public A withNewFilter(StringBuffer arg1){
            return (A)withFilter(new String(arg1));
    }

    public String getId(){
            return this.id;
    }

    public A withId(String id){
            this.id=id; return (A) this;
    }

    public Boolean hasId(){
            return this.id != null;
    }

    public A withNewId(String arg1){
            return (A)withId(new String(arg1));
    }

    public A withNewId(StringBuilder arg1){
            return (A)withId(new String(arg1));
    }

    public A withNewId(StringBuffer arg1){
            return (A)withId(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            SinkInfoFluentImpl that = (SinkInfoFluentImpl) o;
            if (uniqueWriterIdentity != null ? !uniqueWriterIdentity.equals(that.uniqueWriterIdentity) :that.uniqueWriterIdentity != null) return false;
            if (updateDestination != null ? !updateDestination.equals(that.updateDestination) :that.updateDestination != null) return false;
            if (updateFilter != null ? !updateFilter.equals(that.updateFilter) :that.updateFilter != null) return false;
            if (updateIncludeChildren != null ? !updateIncludeChildren.equals(that.updateIncludeChildren) :that.updateIncludeChildren != null) return false;
            if (destination != null ? !destination.equals(that.destination) :that.destination != null) return false;
            if (filter != null ? !filter.equals(that.filter) :that.filter != null) return false;
            if (id != null ? !id.equals(that.id) :that.id != null) return false;
            return true;
    }




}
